ASDiscoveryDescriptorRange

Struct ASDiscoveryDescriptorRange 

#[repr(transparent)]
pub struct ASDiscoveryDescriptorRange(pub NSInteger);
Available on crate feature ASDiscoveryDescriptor only.
Discovery Range

See also Apple’s documentation

Tuple Fields

0: NSInteger

Implementations

Source

impl ASDiscoveryDescriptorRange

pub const Default: Self

The default range in which to discover accessories.

pub const Immediate: Self

A range in the immediate vicinity of the device performing accessory discovery.

This range means that an accessory is right next to the device running your app.